POS filter
===========

![image](icons/filter.svg)

Filter on POS tags

Signals
-------

- Preprocessed Corpus

**Outputs**:

- Corpus

Description
-----------

Given a corpus with POS tags (using the preprocess text widget), filter on POS tags.